# Change Log
All notable changes to this project will be documented in this file.

* This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
* The format of this log is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).


## [Unreleased]

[Documentation](https://cr-nimble.readthedocs.io/en/latest/)


## [0.1.1] - 2021-12-07

### Added

- distance, matrix, ndarray, metrics, modules were moved from `cr-sparse` to `cr-nimble`
- some more vector functions were moved from `cr-sparse` to `cr-nimble`

### Improved

- All unit tests were moved to 64-bit floating point data.


## [0.1.0] - 2021-12-07

Initial release by refactoring code from `cr-nimble`.


[Unreleased]: https://github.com/carnotresearch/cr-nimble/compare/v0.1.1...HEAD
[0.1.1]: https://github.com/carnotresearch/cr-nimble/compare/0.1.0...v0.1.1
[0.1.0]: https://github.com/carnotresearch/cr-nimble/releases/tag/v0.1.0